Messenger Client
================

``MessengerClient`` handles all Messenger related actions and events. 
such as listening to messages, sending messages interacting with users etc. 


.. autoclass:: fbchat_muqit.MessengerClient
   :members: __init__, uid, name
   :show-inheritance:


